@@ -18,6 +18,8 @@ class _BaseConfig:
         self._inner = False if _inner is None else True
         if not self._inner:
             return
+        # KPL_ENV: notebook/pipeline/deploy
+        self._env_type = os.getenv("KPL_ENV")
         self._input_root = os.getenv("KPL_ENV_INPUT_ROOT_PATH")
         self._output_root = os.getenv("KPL_ENV_OUTPUT_ROOT_PATH", "/")
         self._parameter = os.getenv("KPL_ENV_PARAMETER")
@@ -72,6 +74,11 @@ class _BaseConfig:
             return ""
         return self._metric_token
 
+    def get_env_type(self):
+        if not self._inner:
+            return None
+        return self._env_type
+
     def get_cluster(self):
         pass
 
