@@ -6,7 +6,7 @@ logger = logging.getLogger("kpl-helper")
 
 def get_input_path(key, default=""):
     inner = get_config().get_inner()
-    if not inner:
+    if not inner or get_config().get_env_type() == "notebook":
         return default
     root = get_config().get_input_root()
     path = os.path.join(root, str(key))
@@ -17,7 +17,7 @@ def get_input_path(key, default=""):
 
 def get_output_path(key, default=""):
     inner = get_config().get_inner()
-    if not inner:
+    if not inner or get_config().get_env_type() == "notebook":
         return default
     root = get_config().get_output_root()
     path = os.path.join(root, str(key))
