@@ -3,7 +3,7 @@ from kpl_helper.base import _ResultType, _send_result, logger, get_config
 
 def send_progress(progress):
     """
-    :param progress: 百分比进度，值范围：0.0 ~ 1.0
+    :param progress: program progress. value range：0.0 ~ 1.0 (i.e. 0.0% ~ 100%)
     :return:
     """
     if not get_config().get_inner():
@@ -14,8 +14,3 @@ def send_progress(progress):
         if progress > 1.0: progress = 1.0
     _send_result(_ResultType.PROGRESS, "progress", progress)
 
-
-if __name__ == '__main__':
-    for i in range(100):
-        print("send progress")
-        send_progress(i * 0.01)
