@@ -14,6 +14,20 @@ HAN_SCRIPT_PAT = re.compile(
 MB = 1024 * 1024
 
 
+def is_archive_file(path):
+    if os.path.isdir(path):
+        return False
+    if path.endswith(".tar") or path.endswith(".tar.gz") or path.endswith(".zip"):
+        return True
+    return False
+
+
+def assert_symbol_link(path):
+    path = os.path.abspath(path)
+    if os.path.islink(path):
+        raise Exception("[kpl-helper]: `{}` is symbol link. cannot make archive".format(path))
+
+
 class _UploadProgress:
     def __init__(self, total, bar_size=50):
         if total < 1024:
@@ -95,20 +109,24 @@ class Uploader:
             )
             monitor = MultipartEncoderMonitor(encoder, upload_callback)
             self.post(route, data=monitor, headers={'Content-Type': monitor.content_type})
-            # self.post(route,
-            #           data={"name": name, "description": desc},
-            #           files={"file": (os.path.basename(upload_file), fi)})
         bar.close()
         if make_archive:
             os.remove(upload_file)
 
     def upload_dataset(self, name, desc, path):
-        self._upload("/upload/dataset", name, desc, path, True)
+        # 如果是单个文件，且是.tar/.tar.gz/.zip文件，则直接上传
+        # 如果是单个文件，且非.tar/.tar.gz/.zip文件，则需要对文件打包上传
+        # 如果是文件夹，则需要对目录打包上传
+        self._upload("/upload/dataset", name, desc, path, not is_archive_file(path))
 
     def upload_dataset_fs(self, name, desc, path):
-        self._upload("/upload/dataset_fs", name, desc, path, True)
+        # 如果是单个文件，且是.tar/.tar.gz/.zip文件，则直接上传
+        # 如果是单个文件，且非.tar/.tar.gz/.zip文件，则需要对文件打包上传
+        # 如果是文件夹，则需要对目录打包上传
+        self._upload("/upload/dataset_fs", name, desc, path, not is_archive_file(path))
 
     def upload_model(self, name, desc, path):
+        # 模型如果是单个文件则不需要打包，否则需要打包成.tar文件再上传
         self._upload("/upload/model", name, desc, path, os.path.isdir(path))
 
 
